@@ -76,29 +76,30 @@ options:
         required: false
         type: dict
         suboptions:
-            access-banner:
+            access_banner:
+                aliases: ['access-banner']
                 type: str
                 description:
-                    - Deprecated, please rename it to access_banner.
                     - Enable/disable access banner.
                     - disable - Disable setting.
                     - enable - Enable setting.
                 choices:
                     - 'disable'
                     - 'enable'
-            admin-https-redirect:
+            admin_https_redirect:
+                aliases: ['admin-https-redirect']
                 type: str
                 description:
-                    - Deprecated, please rename it to admin_https_redirect.
                     - Enable/disable redirection of HTTP admin traffic to HTTPS.
                     - disable - Disable setting.
                     - enable - Enable setting.
                 choices:
                     - 'disable'
                     - 'enable'
-            admin-login-max:
+            admin_login_max:
+                aliases: ['admin-login-max']
                 type: int
-                description: Deprecated, please rename it to admin_login_max. Maximum number admin users logged in at one time
+                description: Maximum number admin users logged in at one time
             admin_server_cert:
                 type: str
                 description: HTTPS & Web Service server certificate.
@@ -111,32 +112,34 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            auto-update:
+            auto_update:
+                aliases: ['auto-update']
                 type: str
                 description:
-                    - Deprecated, please rename it to auto_update.
                     - Enable/disable FortiGate automatic update.
                     - disable - Disable device automatic update.
                     - enable - Enable device automatic update.
                 choices:
                     - 'disable'
                     - 'enable'
-            banner-message:
+            banner_message:
+                aliases: ['banner-message']
                 type: str
-                description: Deprecated, please rename it to banner_message. Banner message.
-            chassis-mgmt:
+                description: Banner message.
+            chassis_mgmt:
+                aliases: ['chassis-mgmt']
                 type: str
                 description:
-                    - Deprecated, please rename it to chassis_mgmt.
                     - Enable or disable chassis management.
                     - disable - Disable setting.
                     - enable - Enable setting.
                 choices:
                     - 'disable'
                     - 'enable'
-            chassis-update-interval:
+            chassis_update_interval:
+                aliases: ['chassis-update-interval']
                 type: int
-                description: Deprecated, please rename it to chassis_update_interval. Chassis background update interval
+                description: Chassis background update interval
             device_sync_status:
                 type: str
                 description:
@@ -146,10 +149,10 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            gui-theme:
+            gui_theme:
+                aliases: ['gui-theme']
                 type: str
                 description:
-                    - Deprecated, please rename it to gui_theme.
                     - Color scheme to use for the administration GUI.
                     - blue - Blueberry
                     - green - Kiwi
@@ -224,26 +227,28 @@ options:
             idle_timeout:
                 type: int
                 description: Idle timeout
-            install-ifpolicy-only:
+            install_ifpolicy_only:
+                aliases: ['install-ifpolicy-only']
                 type: str
                 description:
-                    - Deprecated, please rename it to install_ifpolicy_only.
                     - Allow install interface policy only.
                     - disable - Disable setting.
                     - enable - Enable setting.
                 choices:
                     - 'disable'
                     - 'enable'
-            mgmt-addr:
+            mgmt_addr:
+                aliases: ['mgmt-addr']
                 type: str
-                description: Deprecated, please rename it to mgmt_addr. IP of FortiManager used by FGFM.
-            mgmt-fqdn:
+                description: IP of FortiManager used by FGFM.
+            mgmt_fqdn:
+                aliases: ['mgmt-fqdn']
                 type: str
-                description: Deprecated, please rename it to mgmt_fqdn. FQDN of FortiManager used by FGFM.
-            objects-force-deletion:
+                description: FQDN of FortiManager used by FGFM.
+            objects_force_deletion:
+                aliases: ['objects-force-deletion']
                 type: str
                 description:
-                    - Deprecated, please rename it to objects_force_deletion.
                     - Enable/disable used objects force deletion.
                     - disable - Disable setting.
                     - enable - Enable setting.
@@ -262,73 +267,74 @@ options:
             register_passwd:
                 type: raw
                 description: (list) Password for register a device.
-            sdwan-monitor-history:
+            sdwan_monitor_history:
+                aliases: ['sdwan-monitor-history']
                 type: str
                 description:
-                    - Deprecated, please rename it to sdwan_monitor_history.
                     - Enable/disable hostname display in the GUI login page.
                     - disable - Disable setting.
                     - enable - Enable setting.
                 choices:
                     - 'disable'
                     - 'enable'
-            shell-access:
+            shell_access:
+                aliases: ['shell-access']
                 type: str
                 description:
-                    - Deprecated, please rename it to shell_access.
                     - Enable/disable shell access.
                     - disable - Disable setting.
                     - enable - Enable setting.
                 choices:
                     - 'disable'
                     - 'enable'
-            shell-password:
+            shell_password:
+                aliases: ['shell-password']
                 type: raw
-                description: (list) Deprecated, please rename it to shell_password. Password for shell access.
-            show-add-multiple:
+                description: (list) Password for shell access.
+            show_add_multiple:
+                aliases: ['show-add-multiple']
                 type: str
                 description:
-                    - Deprecated, please rename it to show_add_multiple.
                     - Show add multiple button.
                     - disable - Disable setting.
                     - enable - Enable setting.
                 choices:
                     - 'disable'
                     - 'enable'
-            show-adom-devman:
+            show_adom_devman:
+                aliases: ['show-adom-devman']
                 type: str
                 description:
-                    - Deprecated, please rename it to show_adom_devman.
                     - Show ADOM device manager tools on GUI.
                     - disable - Hide device manager tools on GUI.
                     - enable - Show device manager tools on GUI.
                 choices:
                     - 'disable'
                     - 'enable'
-            show-checkbox-in-table:
+            show_checkbox_in_table:
+                aliases: ['show-checkbox-in-table']
                 type: str
                 description:
-                    - Deprecated, please rename it to show_checkbox_in_table.
                     - Show checkboxs in tables on GUI.
                     - disable - Disable setting.
                     - enable - Enable setting.
                 choices:
                     - 'disable'
                     - 'enable'
-            show-device-import-export:
+            show_device_import_export:
+                aliases: ['show-device-import-export']
                 type: str
                 description:
-                    - Deprecated, please rename it to show_device_import_export.
                     - Enable/disable import/export of ADOM, device, and group lists.
                     - disable - Disable setting.
                     - enable - Enable setting.
                 choices:
                     - 'disable'
                     - 'enable'
-            show-hostname:
+            show_hostname:
+                aliases: ['show-hostname']
                 type: str
                 description:
-                    - Deprecated, please rename it to show_hostname.
                     - Enable/disable hostname display in the GUI login page.
                     - disable - Disable setting.
                     - enable - Enable setting.
@@ -402,42 +408,44 @@ options:
                     - 'korean'
                     - 'spanish'
                     - 'french'
-            show-fct-manager:
+            show_fct_manager:
+                aliases: ['show-fct-manager']
                 type: str
                 description:
-                    - Deprecated, please rename it to show_fct_manager.
                     - Enable/disable FCT manager.
                     - disable - Disable setting.
                     - enable - Enable setting.
                 choices:
                     - 'disable'
                     - 'enable'
-            sdwan-skip-unmapped-input-device:
+            sdwan_skip_unmapped_input_device:
+                aliases: ['sdwan-skip-unmapped-input-device']
                 type: str
                 description:
-                    - Deprecated, please rename it to sdwan_skip_unmapped_input_device.
                     - Skip unmapped interface for sdwan/rule/input-device instead of report mapping error.
                     - disable - Disable setting.
                     - enable - Enable setting.
                 choices:
                     - 'disable'
                     - 'enable'
-            auth-addr:
+            auth_addr:
+                aliases: ['auth-addr']
                 type: str
-                description: Deprecated, please rename it to auth_addr. IP which is used by FGT to authorize FMG.
-            auth-port:
+                description: IP which is used by FGT to authorize FMG.
+            auth_port:
+                aliases: ['auth-port']
                 type: int
-                description: Deprecated, please rename it to auth_port. Port which is used by FGT to authorize FMG.
+                description: Port which is used by FGT to authorize FMG.
             idle_timeout_api:
                 type: int
                 description: Idle timeout for API sessions
             idle_timeout_gui:
                 type: int
                 description: Idle timeout for GUI sessions
-            central-ftgd-local-cat-id:
+            central_ftgd_local_cat_id:
+                aliases: ['central-ftgd-local-cat-id']
                 type: str
                 description:
-                    - Deprecated, please rename it to central_ftgd_local_cat_id.
                     - Central FortiGuard local category id management, and do not auto assign id during installation.
                     - disable - Disable setting.
                     - enable - Enable setting.
@@ -447,58 +455,73 @@ options:
             idle_timeout_sso:
                 type: int
                 description: Idle timeout for SSO sessions
-            preferred-fgfm-intf:
+            preferred_fgfm_intf:
+                aliases: ['preferred-fgfm-intf']
                 type: str
-                description: Deprecated, please rename it to preferred_fgfm_intf. Preferred interface for FGFM connection.
-            traffic-shaping-history:
+                description: Preferred interface for FGFM connection.
+            traffic_shaping_history:
+                aliases: ['traffic-shaping-history']
                 type: str
                 description:
-                    - Deprecated, please rename it to traffic_shaping_history.
                     - Enable/disable traffic-shaping-history.
                     - disable - Disable setting.
                     - enable - Enable setting.
                 choices:
                     - 'disable'
                     - 'enable'
-            fsw-ignore-platform-check:
+            fsw_ignore_platform_check:
+                aliases: ['fsw-ignore-platform-check']
                 type: str
                 description:
-                    - Deprecated, please rename it to fsw_ignore_platform_check.
                     - Enable/disable FortiSwitch Manager switch platform support check.
                     - disable - Disable setting.
                     - enable - Enable setting.
                 choices:
                     - 'disable'
                     - 'enable'
-            rtm-max-monitor-by-days:
+            rtm_max_monitor_by_days:
+                aliases: ['rtm-max-monitor-by-days']
                 type: int
-                description: Deprecated, please rename it to rtm_max_monitor_by_days. Maximum rtm monitor
-            rtm-temp-file-limit:
+                description: Maximum rtm monitor
+            rtm_temp_file_limit:
+                aliases: ['rtm-temp-file-limit']
                 type: int
-                description: Deprecated, please rename it to rtm_temp_file_limit. Set rtm monitor temp file limit by hours.
-            firmware-upgrade-check:
+                description: Set rtm monitor temp file limit by hours.
+            firmware_upgrade_check:
+                aliases: ['firmware-upgrade-check']
                 type: str
                 description:
-                    - Deprecated, please rename it to firmware_upgrade_check.
                     - Enable/disable firmware upgrade check.
                     - disable - Disable setting.
                     - enable - Enable setting.
                 choices:
                     - 'disable'
                     - 'enable'
-            fgt-gui-proxy:
+            fgt_gui_proxy:
+                aliases: ['fgt-gui-proxy']
                 type: str
                 description:
-                    - Deprecated, please rename it to fgt_gui_proxy.
                     - Enable/disable FortiGate GUI proxy.
                     - disable - Disable setting.
                     - enable - Enable setting.
                 choices:
                     - 'disable'
                     - 'enable'
-            fgt-gui-proxy-port:
+            fgt_gui_proxy_port:
+                aliases: ['fgt-gui-proxy-port']
                 type: int
-                description: Deprecated, please rename it to fgt_gui_proxy_port. FortiGate GUI proxy port.
+                description: FortiGate GUI proxy port.
+            object_threshold_limit:
+                aliases: ['object-threshold-limit']
+                type: str
+                description: Object threshold limit.
+                choices:
+                    - 'disable'
+                    - 'enable'
+            object_threshold_limit_value:
+                aliases: ['object-threshold-limit-value']
+                type: int
+                description: Object threshold limit value.
 '''
 
 EXAMPLES = '''
@@ -568,6 +591,8 @@ EXAMPLES = '''
           firmware_upgrade_check: <value in [disable, enable]>
           fgt_gui_proxy: <value in [disable, enable]>
           fgt_gui_proxy_port: <integer>
+          object_threshold_limit: <value in [disable, enable]>
+          object_threshold_limit_value: <integer>
 '''
 
 RETURN = '''
@@ -611,21 +636,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/admin/setting'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/admin/setting/{setting}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -662,8 +680,8 @@ def main():
                 'offline_mode': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'register_passwd': {'no_log': True, 'type': 'raw'},
                 'sdwan-monitor-history': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'shell-access': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'shell-password': {'no_log': True, 'type': 'raw'},
+                'shell-access': {'v_range': [['6.0.0', '7.2.5'], ['7.4.0', '7.4.3']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'shell-password': {'v_range': [['6.0.0', '7.2.5'], ['7.4.0', '7.4.3']], 'no_log': True, 'type': 'raw'},
                 'show-add-multiple': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'show-adom-devman': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'show-checkbox-in-table': {'choices': ['disable', 'enable'], 'type': 'str'},
@@ -684,18 +702,19 @@ def main():
                 'auth-port': {'v_range': [['7.0.0', '']], 'type': 'int'},
                 'idle_timeout_api': {'v_range': [['6.4.6', '']], 'type': 'int'},
                 'idle_timeout_gui': {'v_range': [['6.4.6', '']], 'type': 'int'},
-                'central-ftgd-local-cat-id': {'v_range': [['6.4.6', '6.4.14'], ['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'central-ftgd-local-cat-id': {'v_range': [['6.4.6', '6.4.15'], ['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'idle_timeout_sso': {'v_range': [['7.0.3', '']], 'type': 'int'},
                 'preferred-fgfm-intf': {'v_range': [['7.0.2', '']], 'type': 'str'},
                 'traffic-shaping-history': {'v_range': [['7.0.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'fsw-ignore-platform-check': {'v_range': [['7.0.7', '7.0.12'], ['7.2.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'fsw-ignore-platform-check': {'v_range': [['7.0.7', '7.0.13'], ['7.2.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'rtm-max-monitor-by-days': {'v_range': [['7.2.2', '']], 'type': 'int'},
                 'rtm-temp-file-limit': {'v_range': [['7.2.2', '']], 'type': 'int'},
                 'firmware-upgrade-check': {'v_range': [['7.2.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'fgt-gui-proxy': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'fgt-gui-proxy-port': {'v_range': [['7.4.2', '']], 'type': 'int'}
+                'fgt-gui-proxy-port': {'v_range': [['7.4.2', '']], 'type': 'int'},
+                'object-threshold-limit': {'v_range': [['7.6.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'object-threshold-limit-value': {'v_range': [['7.6.2', '']], 'type': 'int'}
             }
-
         }
     }
 
@@ -704,14 +723,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_admin_setting'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
